float4x4 World;
float4x4 View;
float4x4 Projection;
float4 Light;

struct VertexShaderInput
{
    float4 Position : POSITION0;
    float3 Normal : NORMAL0;
};

struct VertexShaderOutput
{
    float4 Position : POSITION0;	// transformed position
    float3 Normal : TEXCOORD1;		// normalized surface normal vector
};

VertexShaderOutput VertexShaderFunction(VertexShaderInput input)
{
    VertexShaderOutput output;

	// transform position
    float4 worldPosition = mul(input.Position, World);
    float4 viewPosition = mul(worldPosition, View);
    output.Position = mul(viewPosition, Projection);

	// transform a surface normal from model space to world space, and normalize it
	output.Normal = normalize(mul(input.Normal, World));
	
    return output;
}

float4 PixelShaderFunction(VertexShaderOutput input) : COLOR0
{
    // TODO: add your pixel shader code here.

    float ambientIntensity = 0.8f;
    float4 ambientColor = float4(0.2f, 0.2f, 0.2f, 1.0f);
	float4 ambient = ambientIntensity * ambientColor;
	
    // The dot product gives the angle between two vectors. We  than use the saturate function to clamp the value between 0 and 1.
    float diffuseIntensity = 1.0f;
    float4 diffuseColor = float4(1.0f, 0.0f, 0.0f, 1.0f);
	float4 diffuse = diffuseIntensity * diffuseColor * saturate(dot(input.Normal, Light));
	
    return (ambient + diffuse);
}

technique AmbientDiffuseLightTechnique
{
    pass Pass1
    {
        // TODO: set renderstates here.

        VertexShader = compile vs_1_1 VertexShaderFunction();
        PixelShader = compile ps_1_1 PixelShaderFunction();
    }
}
